@@ -1,5 +1,5 @@
 /*
- * $Id: ConnectionSettings.cpp 129 2012-04-07 10:15:46Z wejaeger $
+ * $Id: ConnectionSettings.cpp 153 2012-10-11 04:47:46Z wejaeger $
  *
  * File:   ConnectionSettings.cpp
  * Author: Werner Jaeger
@@ -188,9 +188,14 @@ int ConnectionSettings::deleteAllConfFiles()
    {
       for (int i = 0; i < ConfWriter::END; i++)
       {
-         const QString strConfFile(ConfWriter::fileName(static_cast<ConfWriter::Conf>(i)));
-         if (QFile::exists(strConfFile))
-            QFile::remove(strConfFile);
+         const ConfWriter::Conf conf(static_cast<ConfWriter::Conf>(i));
+
+         if (conf != ConfWriter::IPsec && conf != ConfWriter::L2TP && conf != ConfWriter::IPsecSECRET)
+         {
+            const QString strConfFile(ConfWriter::fileName(conf));
+            if (QFile::exists(strConfFile))
+               QFile::remove(strConfFile);
+         }
       }
 
       const int iConnections(connections());
